@@ -322,14 +322,20 @@ namespace Tomboy
 				"",
 				Catalog.GetString ("Contributors:"),
 				"\tAaron Bockover",
+				"\tAaron Bordern",
+				"\tAlejandro Cura",
 				"\tAlexey Nedilko",
 				"\tAlex Kloss",
 				"\tAnders Petersson",
 				"\tAndrew Fister",
 				"\tBenjamin Podszun",
+				"\tBrian Mattern",
+				"\tBrion Vibber",
 				"\tBuchner Johannes",
+				"\tCarlos Arenas",
 				"\tChris Scobell",
 				"\tClemens N. Buss",
+				"\tCory Thomas",
 				"\tDave Foster",
 				"\tDavid Trowbridge",
 				"\tDoug Johnston",
@@ -342,8 +348,10 @@ namespace Tomboy
 				"\tJames Westby",
 				"\tJamin Philip Gray",
 				"\tJan Rüegg",
+				"\tJavier Jardón",
 				"\tJay R. Wren",
 				"\tJeffrey Stedfast",
+				"\tJeff Stoner",
 				"\tJeff Tickle",
 				"\tJerome Haltom",
 				"\tJoe Shaw",
@@ -356,11 +364,13 @@ namespace Tomboy
 				"\tŁukasz Jernaś",
 				"\tMark Wakim",
 				"\tMathias Hasselmann",
+				"\tMatthew Pirocchi",
 				"\tMatt Johnston",
 				"\tMatt Jones",
 				"\tMike Mazur",
 				"\tNathaniel Smith",
 				"\tOlivier Le Thanh Duong",
+				"\tOwen Williams",
 				"\tPaul Cutler",
 				"\tPrzemysław Grzegorczyk",
 				"\tRobert Buchholz",
@@ -372,6 +382,7 @@ namespace Tomboy
 				"\tSebastian Rittau",
 				"\tStefan Cosma",
 				"\tStefan Schweizer",
+				"\tTobias Abenius",
 				"\tTommi Asiala",
 				"\tWouter Bolsterlee",
 				"\tYonatan Oren"
@@ -381,8 +392,10 @@ namespace Tomboy
 				"Alex Graveley <alex@beatniksoftware.com>",
 				"Boyd Timothy <btimothy@gmail.com>",
 				"Brent Smith <gnome@nextreality.net>",
+				"Laurent Codeur <laurentc@iol.ie>",
 				"Paul Cutler <pcutler@foresightlinux.org>",
-				"Sandy Armstrong <sanfordarmstrong@gmail.com>"
+				"Sandy Armstrong <sanfordarmstrong@gmail.com>",
+				"Stefan Schweizer <steve.schweizer@gmail.com>"
 			};
 
 			string translators = Catalog.GetString ("translator-credits");
@@ -395,7 +408,7 @@ namespace Tomboy
 			about.Logo = GuiUtils.GetIcon ("tomboy", 48);
 			about.Copyright =
 			        Catalog.GetString ("Copyright \xa9 2004-2007 Alex Graveley\n" +
-				                   "Copyright \xa9 2004-2009 Others\n");
+				                   "Copyright \xa9 2004-2010 Others\n");
 			about.Comments = Catalog.GetString ("A simple and easy to use desktop " +
 			                                    "note-taking application.");
 			Gtk.AboutDialog.SetUrlHook (delegate (Gtk.AboutDialog dialog, string link) {
