@@ -452,7 +452,7 @@ namespace Tomboy
 		void OpenUrl (string url)
 		{
 			if (url != string.Empty) {
-				Logger.Log ("Opening url '{0}'...", url);
+				Logger.Debug ("Opening url '{0}'...", url);
 				Services.NativeApplication.OpenUrl (url, Note.Window.Screen);
 			}
 		}
@@ -720,7 +720,7 @@ namespace Tomboy
 			if (title_start.HasTag (Note.TagTable.UrlTag))
 				return;
 
-			Logger.Log ("Matching Note title '{0}' at {1}-{2}...",
+			Logger.Debug ("Matching Note title '{0}' at {1}-{2}...",
 			            hit.Key,
 			            hit.Start,
 			            hit.End);
@@ -799,7 +799,7 @@ namespace Tomboy
 			Note link = Manager.Find (link_name);
 
 			if (link == null) {
-				Logger.Log ("Creating note '{0}'...", link_name);
+				Logger.Debug ("Creating note '{0}'...", link_name);
 				try {
 					link = Manager.Create (link_name);
 				} catch {
@@ -814,7 +814,7 @@ namespace Tomboy
 		// as the current note's title, it's safe to omit this check and
 		// also works around the bug.
 		if (link != null) {
-				Logger.Log ("Opening note '{0}' on click...", link_name);
+				Logger.Debug ("Opening note '{0}' on click...", link_name);
 				link.Window.Present ();
 				return true;
 			}
@@ -892,7 +892,7 @@ namespace Tomboy
 			                match = match.NextMatch ()) {
 				System.Text.RegularExpressions.Group group = match.Groups [1];
 
-				Logger.Log ("Highlighting wikiword: '{0}' at offset {1}",
+				Logger.Debug ("Highlighting wikiword: '{0}' at offset {1}",
 				            group,
 				            group.Index);
 
@@ -1010,13 +1010,6 @@ namespace Tomboy
 		[GLib.ConnectBefore]
 		void OnEditorMotion (object sender, Gtk.MotionNotifyEventArgs args)
 		{
-			int pointer_x, pointer_y;
-			Gdk.ModifierType pointer_mask;
-
-			Window.Editor.GdkWindow.GetPointer (out pointer_x,
-			                                    out pointer_y,
-			                                    out pointer_mask);
-
 			bool hovering = false;
 
 			// Figure out if we're on a link by getting the text
@@ -1025,8 +1018,8 @@ namespace Tomboy
 
 			int buffer_x, buffer_y;
 			Window.Editor.WindowToBufferCoords (Gtk.TextWindowType.Widget,
-			                                    pointer_x,
-			                                    pointer_y,
+			                                    (int)args.Event.X,
+			                                    (int)args.Event.Y,
 			                                    out buffer_x,
 			                                    out buffer_y);
 
@@ -1040,8 +1033,8 @@ namespace Tomboy
 			}
 
 			// Don't show hand if Shift or Control is pressed
-			bool avoid_hand = (pointer_mask & (Gdk.ModifierType.ShiftMask |
-			                                   Gdk.ModifierType.ControlMask)) != 0;
+			bool avoid_hand = (args.Event.State & (Gdk.ModifierType.ShiftMask |
+			                                       Gdk.ModifierType.ControlMask)) != 0;
 
 			if (hovering != hovering_on_link) {
 				hovering_on_link = hovering;
